@@ -60,11 +60,12 @@ class TestVariable(unittest.TestCase):
     def setUp(self):
         from ..message import (
             Message,
+            MessageMeta,
             Parameter,
         )
         self.foo = Parameter(str)
         self.bar = Parameter(str, default='hoge')
-        self.msg = type('cls', (Message, ), {
+        self.msg = MessageMeta('cls', (Message, ), {
             'foo': self.foo,
             'bar': self.bar,
         })
@@ -136,12 +137,6 @@ class TestMessageMeta(unittest.TestCase):
             'bar': bar,
         })
 
-        self.assertTrue(hasattr(cls, '__msg_params__'))
-        self.assertEqual(cls.__msg_params__, {
-            'foo': foo,
-            'bar': bar,
-        })
-
         self.assertIsInstance(cls.__dict__['foo'], Variable)
         self.assertIsInstance(cls.__dict__['bar'], Constant)
 
